@@ -4,7 +4,7 @@ options(
     setup=Bunch(
         name="stockpyle",
         packages=["stockpyle"],
-        version="0.0.1",
+        version="0.0.2",
         license="BSD",
         author="Matt Pizzimenti",
         author_email="mjpizz+stockpyle@gmail.com",
@@ -123,7 +123,7 @@ You can use the Storable helper class to get class-level access to the storage A
     
     # bind to a storage object
     store = ProcessMemoryStore()
-    Bar.bind(store)
+    Bar.bind_store(store)
     
     # save an object
     obj = Bar(111, 777)
